@@ -26,18 +26,22 @@
 #' @autoglobal
 #'
 #' @example man/examples/examples-corr-test.R
+#'
+#' @template citation
+#'
 #' @export
 corr_test <- function(
-    data,
-    x,
-    y,
-    type = "parametric",
-    digits = 2L,
-    conf.level = 0.95,
-    tr = 0.2,
-    bf.prior = 0.707,
-    ...) {
-  type <- stats_type_switch(type)
+  data,
+  x,
+  y,
+  type = "parametric",
+  digits = 2L,
+  conf.level = 0.95,
+  tr = 0.2,
+  bf.prior = 0.707,
+  ...
+) {
+  type <- extract_stats_type(type)
 
   stats_df <- correlation::correlation(
     data           = select(ungroup(data), {{ x }}, {{ y }}) %>% tidyr::drop_na(),
