@@ -1,48 +1,6 @@
-#' @title Movie information and user ratings from IMDB.com (wide format).
-#' @name movies_wide
-#' @details Modified dataset from `ggplot2movies` package.
-#'
-#' The internet movie database, <https://imdb.com/>, is a website devoted
-#' to collecting movie data supplied by studios and fans. It claims to be the
-#' biggest movie database on the web and is run by amazon.
-#'
-#' Movies were selected for inclusion if they had a known length and had been
-#' rated by at least one IMDB user. Small categories such as documentaries
-#' and NC-17 movies were removed.
-#'
-#' @format A data frame with 1,579 rows and 13 variables
-#'
-#'   - title.  Title of the movie.
-#'   - year.  Year of release.
-#'   - budget.  Total budget in millions of US dollars
-#'   - length.  Length in minutes.
-#'   - rating.  Average IMDB user rating.
-#'   - votes.  Number of IMDB users who rated this movie.
-#'   - mpaa.  MPAA rating.
-#'   - action, animation, comedy, drama, documentary, romance, short. Binary
-#'     variables representing if movie was classified as belonging to that genre.
-#'   - NumGenre.  The number of different genres a film was classified in an
-#'     integer between one and four.
-#'
-#' @source <https://CRAN.R-project.org/package=ggplot2movies>
-#'
-#' @examples
-#' dim(movies_wide)
-#' head(movies_wide)
-#' dplyr::glimpse(movies_wide)
-"movies_wide"
-
-#' @title Movie information and user ratings from IMDB.com (long format).
+#' @title Movie information and user ratings from IMDB.
 #' @name movies_long
-#' @details Modified dataset from `ggplot2movies` package.
-#'
-#' The internet movie database, <https://imdb.com/>, is a website devoted
-#' to collecting movie data supplied by studios and fans. It claims to be the
-#' biggest movie database on the web and is run by amazon.
-#'
-#' Movies were are identical to those selected for inclusion in movies_wide but this
-#' dataset has been constructed such that every movie appears in one and only one
-#' genre category.
+#' @details Modified dataset from `{ggplot2movies}` package.
 #'
 #' @format A data frame with 1,579 rows and 8 variables
 #'
@@ -72,7 +30,7 @@
 #'   petal length and width, respectively, for 50 flowers from each of 3 species
 #'   of iris. The species are Iris setosa, versicolor, and virginica.
 #'
-#' This is a modified dataset from `datasets` package.
+#' This is a modified dataset from `{datasets}` package.
 #'
 #' @format A data frame with 600 rows and 5 variables
 #'
@@ -114,8 +72,12 @@
 #'   - desire. The desire to kill an arthropod was indicated on a scale from
 #'     0 to 10.
 #'
-#' @source
-#' <https://www.sciencedirect.com/science/article/pii/S0747563213000277>
+#' @references
+#'
+#' Ryan, R. S., Wilde, M., & Crist, S. (2013). Compared to a small, supervised
+#' lab experiment, a large, unsupervised web-based experiment on a previously
+#' unknown effect has benefits that outweigh its potential costs. *Computers in
+#' Human Behavior*, *29*(4), 1295-1301.
 #'
 #' @examples
 #' dim(bugs_long)
